==> u61-1.0.0.tar.gz: u61-1.0.0/src/registeredcurse.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   registeredcurse.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this is a very simple class, used to store information
 *              about the registered curses in the map object.
 */

#ifndef INC_U61_REGISTEREDCURSE
#define INC_U61_REGISTEREDCURSE

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_RegisteredCurse
{ 
 public:
  U61_RegisteredCurse();
  void reset();

  int begin;
  int end;
  bool active;
  bool good;
 protected:  
};

#endif

==> u61-1.1.0.tar.gz: u61-1.1.0/src/registeredcurse.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000-2003 Christian Mauduit (ufoot@ufoot.org)              *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on Savannah (http://savannah.gnu.org)     *
 ****************************************************************************/

/*
 * file name:   registeredcurse.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this is a very simple class, used to store information
 *              about the registered curses in the map object.
 */

#ifndef U61_INC_REGISTEREDCURSE
#define U61_INC_REGISTEREDCURSE

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>


#include "utils.h"

/*---------------------------------------------------------------------------
 constants
 ---------------------------------------------------------------------------*/

#define U61_REGISTEREDCURSE_SERIALIZED_SIZE (2*U61_SERIAL_INT_SERIALIZED_SIZE + 2*U61_SERIAL_BOOL_SERIALIZED_SIZE)

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_RegisteredCurse
{ 
 public:
  U61_RegisteredCurse();
  void reset();

  bool serialize(unsigned char **buffer, unsigned char *buffer_limit);
  bool unserialize(unsigned char **buffer, unsigned char *buffer_limit);

  unsigned int begin;
  unsigned int end;
  bool active;
  bool good;
 protected:  
};

#endif
